@@ -396,10 +396,7 @@ class MessageBus:
         :param handler: A message handler.
         :type handler: :class:`Callable`
         """
-        for i, h in enumerate(self._user_message_handlers):
-            if h == handler:
-                del self._user_message_handlers[i]
-                break
+        self._user_message_handlers.remove(handler)
 
     async def _finalize(self):
         '''should be called after the socket disconnects with the disconnection
@@ -608,11 +605,7 @@ class MessageBus:
             raise DBusError(ErrorType.INTERNAL_ERROR, 'invalid message type for method call', msg)
 
     async def _on_message(self, msg):
-        try:
-            await self._process_message(msg)
-        except Exception as e:
-            logging.error(
-                f'got unexpected error processing a message: {e}.\n{traceback.format_exc()}')
+        await self._process_message(msg)
 
     def _send_reply(self, msg):
         bus = self
@@ -662,20 +655,15 @@ class MessageBus:
                 if msg.message_type == MessageType.METHOD_CALL:
                     await self.send(e._as_message(msg))
                     handled = True
-                    break
-                else:
-                    logging.error(
-                        f'A message handler raised an exception: {e}.\n{traceback.format_exc()}')
+                raise
             except Exception as e:
-                logging.error(
-                    f'A message handler raised an exception: {e}.\n{traceback.format_exc()}')
                 if msg.message_type == MessageType.METHOD_CALL:
                     await self.send(
                         Message.new_error(
                             msg, ErrorType.INTERNAL_ERROR,
                             f'An internal error occurred: {e}.\n{traceback.format_exc()}'))
                     handled = True
-                    break
+                raise
 
         if msg.message_type == MessageType.SIGNAL:
             if msg._matches(
@@ -1138,7 +1126,7 @@ class MessageBus:
                 send_reply(Message.new_method_return(msg, method.out_signature, body, fds))
 
         def _handler(msg, send_reply):
-            self._tg.spawn(handler, msg, send_reply)
+            self._tg.start_soon(handler, msg, send_reply)
 
         return _handler
 
@@ -1157,7 +1145,7 @@ class MessageBus:
                 unmarshaller.feed(data, aux)
 
                 for msg in unmarshaller:
-                    self._tg.spawn(self._on_message, msg)
+                    self._tg.start_soon(self._on_message, msg)
 
     async def _message_writer(self, *, task_status):
         with anyio.open_cancel_scope() as sc:
